@@ -16,18 +16,18 @@ sub options {
 
 
 sub run {
-    my ( $self, $keyword ) = @_;
+    my ( $self, @keywords ) = @_;
 
-    unless( $keyword ) {
+    unless( @keywords ) {
         warn "Please specify keyword";
         exit 0; 
     }
 
     # Search from Index
     my $results = Vimana::VimOnline::Search->fetch(
-        keyword => $keyword,
-        ( $self->{script_type} ? ( script_type => $self->{script_type} ) : ()  ),
-        ( $self->{order_by}    ? ( order_by => $self->{order_by} ) : () ),
+        keywords     => join(' ' , @keywords) ,
+        ( $self->{script_type} ? ( script_type => $self->{script_type} ) : () ),
+        ( $self->{order_by} ? ( order_by => $self->{order_by} )  : () ),
     );
 
     Vimana::VimOnline::SearchResult->display( $results );
